==> Cluckshrooms%281.21%29-1.1.0-sources.jar: fun/wich/CluckshroomEggEntity.java <==
package fun.wich;

import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2392;
import net.minecraft.class_2398;
import net.minecraft.class_3857;
import net.minecraft.class_3966;
import net.minecraft.class_4048;
import net.minecraft.class_6024;
import net.minecraft.entity.*;

public class CluckshroomEggEntity extends class_3857 {
	protected static final class_4048 EMPTY_DIMENSIONS = class_4048.method_18385(0, 0);
	public CluckshroomEggEntity(class_1299<? extends CluckshroomEggEntity> entityType, class_1937 world) { super(entityType, world); }
	public CluckshroomEggEntity(class_1937 world, class_1309 owner) {
		super(CluckshroomMod.CLUCKSHROOM_EGG, owner, world);
	}
	public CluckshroomEggEntity(class_1937 world, double x, double y, double z, class_1799 stack) {
		super(CluckshroomMod.CLUCKSHROOM_EGG, x, y, z, world);
		this.method_16940(stack);
	}
	@Override
	public void method_5711(byte status) {
		if (status == 3) {
			for (int i = 0; i < 8; ++i) {
				this.method_5770().method_8406(new class_2392(class_2398.field_11218, this.method_7495()), this.method_23317(), this.method_23318(), this.method_23321(), (this.field_5974.method_43057() - 0.5) * 0.08, (this.field_5974.method_43057() - 0.5) * 0.08, (this.field_5974.method_43057() - 0.5) * 0.08);
			}
		}
	}
	@Override
	protected void method_7454(class_3966 entityHitResult) {
		super.method_7454(entityHitResult);
		entityHitResult.method_17782().method_5643(this.method_48923().method_48811(this, this.method_24921()), 0);
	}
	@Override
	protected void method_7488(class_239 hitResult) {
		super.method_7488(hitResult);
		if (!this.method_5770().method_8608()) {
			if (this.field_5974.method_43048(8) == 0) {
				int i = 1;
				if (this.field_5974.method_43048(32) == 0) i = 4;
				for (int j = 0; j < i; j++) {
					CluckshroomEntity entity = CluckshroomMod.CLUCKSHROOM.method_5883(this.method_5770());
					if (entity != null) {
						entity.method_5614(-24000);
						entity.method_5808(this.method_23317(), this.method_23318(), this.method_23321(), this.method_36454(), 0);
						class_1799 stack = this.method_7495();
						if (stack.method_31574(CluckshroomMod.RED_CLUCKSHROOM_EGG)) entity.setVariant(CluckshroomEntity.Variant.RED);
						else if (stack.method_31574(CluckshroomMod.BROWN_CLUCKSHROOM_EGG)) entity.setVariant(CluckshroomEntity.Variant.BROWN);
						if (!entity.method_60490(EMPTY_DIMENSIONS)) break;
						this.method_5770().method_8649(entity);
					}
				}
			}
			this.method_5770().method_8421(this, class_6024.field_30028);
			this.method_31472();
		}
	}
	@Override protected class_1792 method_16942() { return CluckshroomMod.RED_CLUCKSHROOM_EGG; }
}

==> Cluckshrooms%281.21.5%29-1.1.1-sources.jar: fun/wich/CluckshroomEggEntity.java <==
package fun.wich;

import net.minecraft.class_1299;
import net.minecraft.class_1309;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_239;
import net.minecraft.class_2392;
import net.minecraft.class_2398;
import net.minecraft.class_3730;
import net.minecraft.class_3857;
import net.minecraft.class_3966;
import net.minecraft.class_4048;
import net.minecraft.class_6024;
import net.minecraft.entity.*;

public class CluckshroomEggEntity extends class_3857 {
	protected static final class_4048 EMPTY_DIMENSIONS = class_4048.method_18385(0, 0);
	public CluckshroomEggEntity(class_1299<? extends CluckshroomEggEntity> entityType, class_1937 world) { super(entityType, world); }
	public CluckshroomEggEntity(class_1937 world, class_1309 owner, class_1799 stack) {
		super(CluckshroomMod.CLUCKSHROOM_EGG, owner, world, stack);
	}
	public CluckshroomEggEntity(class_1937 world, double x, double y, double z, class_1799 stack) {
		super(CluckshroomMod.CLUCKSHROOM_EGG, x, y, z, world, stack);
	}
	@Override
	public void method_5711(byte status) {
		if (status == 3) {
			for (int i = 0; i < 8; ++i) {
				this.method_5770().method_8406(new class_2392(class_2398.field_11218, this.method_7495()), this.method_23317(), this.method_23318(), this.method_23321(), (this.field_5974.method_43057() - 0.5) * 0.08, (this.field_5974.method_43057() - 0.5) * 0.08, (this.field_5974.method_43057() - 0.5) * 0.08);
			}
		}
	}
	@Override
	protected void method_7454(class_3966 entityHitResult) {
		super.method_7454(entityHitResult);
		//noinspection deprecation
		entityHitResult.method_17782().method_64419(this.method_48923().method_48811(this, this.method_24921()), 0);
	}
	@Override
	protected void method_7488(class_239 hitResult) {
		super.method_7488(hitResult);
		if (!this.method_5770().method_8608()) {
			if (this.field_5974.method_43048(8) == 0) {
				int i = 1;
				if (this.field_5974.method_43048(32) == 0) i = 4;
				for (int j = 0; j < i; j++) {
					CluckshroomEntity entity = CluckshroomMod.CLUCKSHROOM.method_5883(this.method_5770(), class_3730.field_16461);
					if (entity != null) {
						entity.method_5614(-24000);
						entity.method_5808(this.method_23317(), this.method_23318(), this.method_23321(), this.method_36454(), 0);
						class_1799 stack = this.method_7495();
						if (stack.method_31574(CluckshroomMod.RED_CLUCKSHROOM_EGG)) entity.setVariant(CluckshroomEntity.Variant.RED);
						else if (stack.method_31574(CluckshroomMod.BROWN_CLUCKSHROOM_EGG)) entity.setVariant(CluckshroomEntity.Variant.BROWN);
						if (!entity.method_60490(EMPTY_DIMENSIONS)) break;
						this.method_5770().method_8649(entity);
					}
				}
			}
			this.method_5770().method_8421(this, class_6024.field_30028);
			this.method_31472();
		}
	}
	@Override protected class_1792 method_16942() { return CluckshroomMod.RED_CLUCKSHROOM_EGG; }
}
